==> zio-aws-appsync_3-5.17.127.2-sources.jar: zio/aws/appsync/model/GetTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetTypeResponse(
    `type`: Option[zio.aws.appsync.model.Type] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.GetTypeResponse = {
    import GetTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.GetTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.GetTypeResponse.ReadOnly =
    zio.aws.appsync.model.GetTypeResponse.wrap(buildAwsValue())
}
object GetTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.GetTypeResponse =
      zio.aws.appsync.model
        .GetTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Option[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ) extends zio.aws.appsync.model.GetTypeResponse.ReadOnly {
    override val `type`: Option[zio.aws.appsync.model.Type.ReadOnly] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ): zio.aws.appsync.model.GetTypeResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appsync_3-5.17.203.2-sources.jar: zio/aws/appsync/model/GetTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetTypeResponse(
    `type`: Optional[zio.aws.appsync.model.Type] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.GetTypeResponse = {
    import GetTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.GetTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.GetTypeResponse.ReadOnly =
    zio.aws.appsync.model.GetTypeResponse.wrap(buildAwsValue())
}
object GetTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.GetTypeResponse =
      zio.aws.appsync.model
        .GetTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Optional[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ) extends zio.aws.appsync.model.GetTypeResponse.ReadOnly {
    override val `type`: Optional[zio.aws.appsync.model.Type.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.GetTypeResponse
  ): zio.aws.appsync.model.GetTypeResponse.ReadOnly = new Wrapper(impl)
}
